#!/usr/bin/ksh

CURDIR=`pwd`
PRODS="`cat _products.txt | grep -v '^#'`"

if [ -n "$1" ]; then
	PRODS="$1"
fi

for PROD in $PRODS
do
	# First, copy the source files
	echo "=== REMOVING OLD SOURCE FILES FOR $PROD ..."
	rm -rf $PROD
	cd ..
	if [ -d "$PROD" ]; then
		echo "=== COPYING SOURCE FILES FOR $PROD ..."
		find $PROD -print | cpio -pdumv $CURDIR 2>&1 | tee $CURDIR/output/${PROD}_src.out
	else
		echo "=== SKIP COPYING SOURCE FILES FOR $PROD ... NONE EXIST"
	fi
	cd $CURDIR

	# Next, install any additional or very modified source files
	if [ -d "BUILD/$PROD/files" ]; then
		cd BUILD/$PROD/files
		echo "=== COPYING MODIFIED SOURCE FILES FOR $PROD ..."
		find * -print | cpio -pdumv ../../../$PROD 2>&1 | tee -a $CURDIR/output/${PROD}_src.out
	else
		echo "=== SKIP COPYING MODIFIED SOURCE FILES FOR $PROD ... NONE EXIST"
	fi
	cd $CURDIR

	# Also, run any patch scripts (fixsrc.sh)
	if [ -x "BUILD/$PROD/fixsrc.sh" ]; then
		echo "=== MODIFYING SOURCE FILES FOR $PROD ..."
		cd BUILD/$PROD; ./fixsrc.sh $PROD 2>&1 | tee -a $CURDIR/output/${PROD}_src.out
	else
		echo "=== SKIP MODIFYING SOURCE FILES FOR $PROD ... NONE NECESSARY"
	fi
	if [ -d "$CURDIR/$PROD" ]; then
		echo "=== Changing permissions on files for $PROD"
		find $CURDIR/$PROD -print | xargs chmod 755
	fi
	cd $CURDIR
done
