#!/usr/bin/ksh

CURDIR=`pwd`
PRODS="`cat _products.txt | grep -v '^#'`"
SETS="`cat _sets.txt | grep -v '^#'`"

if [ -n "$1" ]; then
	if [ -n "`grep $1 _products.txt`" ]; then
		PRODS="$1"
		SETS=" "
	elif [ -n "`grep $1 _sets.txt`" ]; then
		PRODS=" "
		SETS="$1"
	else
		echo "$1 not found in _products.txt or _sets.txt!"
		exit 1
	fi
fi

# All the build images go into the image directory
if [ ! -d image ]; then
	mkdir image
fi

# Run the packaging script for any package which needs building
for PROD in $PRODS
do
	if [ -x "BUILD/$PROD/package.sh" ]; then
		echo "=== PACKAGING $PROD ..."
		cd BUILD/$PROD; ./package.sh $PROD 2>&1 | tee ../../output/${PROD}_pkg.out
		cd $CURDIR
	else
		echo "=== PACKAGING $PROD ... NO PACKAGING NEEDED"
	fi
done

# Run the packaging script for any set which needs building
for SET in $SETS
do
	if [ -x "BUILD/$SET/package.sh" ]; then
		echo "=== PACKAGING SET $SET ..."
		cd BUILD/$SET; ./package.sh $SET | tee -a ../../output/${SET}_pkg.out
		cd $CURDIR
	else
		echo "=== PACKAGING SET $SET ... NO PACKAGING NEEDED"
	fi
done
