#! /usr/bin/ksh

set -x
set -e

SRCDIR=`pwd`/../../$1
BLDROOT=`pwd`/../../bin/$1
APCONF=$BLDROOT/opt/apache2/conf

# Must have GNU make installed
if [ ! -x /usr/local/bin/make ]; then
	echo "GNU make must be installed!"
	exit 1
fi

# Need the which command
PATH=/usr/local/bin:$PATH:/usr/ucb

export SRCDIR BLDROOT APCONF
export CC=cc
export LDFLAGS="-O2 -Kpthread -Wl,-Bexport"
export CCFLAGS="-Kpthread -O2"

rm -rf $BLDROOT
mkdir -p $BLDROOT

cd ../../$1/WORKER
make DESTDIR=$BLDROOT install
mkdir -p $BLDROOT/etc/init.d
cp ../apache2.rc $BLDROOT/etc/init.d/apache2
mkdir -p $APCONF/conf.d
mv $BLDROOT/opt/apache2/bin/httpd $BLDROOT/opt/apache2/bin/httpd.worker
cp ../PREFORK/.libs/httpd $BLDROOT/opt/apache2/bin/httpd.prefork
# Fix the httpd.conf file
REPS="LoadModule rewrite_module modules/mod_rewrite.so"
perl -pi -e "
	s%${REPS}%${REPS}\n\nInclude conf/conf.d/\*%g;
	s%^User .*%User nobody%g;
	s%^Group .*%Group nobody%g;
	" $BLDROOT/opt/apache2/conf/httpd.conf
cd $BLDROOT/opt/apache2/bin
ln -s httpd.prefork httpd

# Lastly, create the certificates
for suffix in in crl crt csr key prm; do
	mkdir -p $APCONF/ssl.${suffix}
	chmod 700 $APCONF/ssl.${suffix}
done
if [ ! -f $APCONF/ssl.key/server.key ]; then
	openssl genrsa 1024 > $APCONF/ssl.key/server.key
fi
FQDN=`hostname`
if [ ! -f $APCONF/ssl.crt/server.crt ]; then
	cat << EOF | openssl req -new -key $APCONF/ssl.key/server.key \
		-x509 -days 365 -out $APCONF/ssl.crt/server.crt
--
SomeState
SomeCity
SomeOrganization
SomeOrganizationalUnit
${FQDN}
root@${FQDN}
EOF
fi
