#! /usr/bin/ksh

set -x
set -e

cd ../../$1

CURDIR="`pwd`"
PATH=/opt/bin:/usr/local/bin:$PATH

FILES=" \
	Bundle-libnet \
	libnet \
	HTML-Parser \
	HTML-Tagset \
	IO-Socket-SSL \
	MIME-Base64 \
	libwww-perl \
	CGI.pm \
	CPAN \
	Compress-Zlib \
	Net_SSLeay.pm \
	Crypt-SSLeay \
	Digest-MD5 \
	ExtUtils-MakeMaker \
	FCGI \
	Msgcat \
	Safe \
	Term-ReadLine-Perl \
	TermReadKey \
	URI \
	gettext"

rm -rf opt
mkdir -p opt/lib

for file in $FILES
do
	ZIPFILE="${file}.tar.gz"
	DIR="$file"
	echo "*** Building $DIR ***"
	gunzip -c $ZIPFILE | tar xvf -
	cd ${DIR}-*
	rm -rf opt
	ln -s ../opt opt
	export BUILDROOT=.
	export PERL5LIB=opt/lib
	export OPTIONS="PREFIX=$BUILDROOT/opt"
	case $file in
		Bundle-libnet)
			;;
		CGI.pm)
			;;
		CPAN)
			;;
		Compress-Zlib)
			;;
		Crypt-SSLeay)
			export CRYPT_SSLEAY_DEFAULT=/usr
			;;
		Digest-MD5)
			;;
		Net_SSLeay.pm)
			OPTIONS="-- PREFIX=$BUILDROOT/opt"
			;;
		ExtUtils-MakeMaker)
			;;
		FCGI)
			;;
		HTML-Parser)
			;;
		HTML-Tagset)
			;;
		IO-Socket-SSL)
			;;
		MIME-Base64)
			;;
		Msgcat)
			;;
		Safe)
			;;
		Term-ReadLine-Perl)
			;;
		TermReadKey)
			;;
		URI)
			;;
		gettext)
			;;
		libnet)
			OPTIONS="PREFIX=$BUILDROOT/opt"
			;;
		libwww-perl)
			;;
	esac
	echo "run 'Makefile.PL $OPTIONS'"
	if [ "$file" = "HTML-Parser" ]; then
		# Auto answer "yes" to Unicode string support for HTML-Parser
		echo "yes" | /opt/bin/perl Makefile.PL $OPTIONS
	elif [ "$file" = "libnet" ]; then
		# Auto answer for updating libnet config
		echo "y" | /opt/bin/perl Makefile.PL $OPTIONS
	elif [ "$file" = "libwww-perl" ]; then
		# Auto answer "y" to direct internet testing
		echo "y" | /opt/bin/perl Makefile.PL $OPTIONS
	else 
		/opt/bin/perl Makefile.PL $OPTIONS
	fi
	make
	cd $CURDIR
done

