#! /usr/bin/ksh

set -x
set -e

CURDIR=`pwd`
SRCDIR=$CURDIR/../../$1
BLDROOT=$CURDIR/../../bin/$1

# Must have GNU make installed
if [ ! -x /usr/local/bin/make ]; then
	echo "GNU make must be installed!"
	exit 1
fi

# Need the which command
PATH=/usr/local/bin:$PATH:/usr/ucb:/usr/gnu/bin

export SRCDIR BLDROOT
export CC=cc
export LDFLAGS="-O2 -Kpthread -Wl,-Bexport"
export CCFLAGS="-Kpthread -O2"

rm -rf $BLDROOT
mkdir -p $BLDROOT

fix_bintree () {
	cd $1
	mkdir -p tmp/php
	mkdir -p tmp/pear/packages
	BDIR=`pwd`
	if [ -d usr ]; then
		mkdir old
		mv usr old
		BINS=usr/lib/php
		mkdir -p $BINS
		mkdir -p usr/etc
		cp -pR old/usr/bin usr
		cp -pR old/usr/include usr
		mkdir -p tmp/php
		cp -p old/usr/lib/apache/libexec/libphp4.so tmp/php
	else
		mkdir old
		mv opt old
		BINS=opt/lib/php
		mkdir -p $BINS
		mkdir -p opt/etc
		cp -pR old/opt/bin opt
		cp -pR old/opt/include opt
		mkdir -p tmp/php
		cp old/opt/apache2/modules/libphp4.so.0.0.0 tmp/php/libphp4.so
	fi
	cp -pR old/$BINS/build $BINS
	# Copy over the pear pieces we want
	for f in Archive CMD.php Console OS PEAR PEAR.php System.php catalog docs; do
		cp -R $SRCDIR/pear/$f tmp/pear
	done
	cp $SRCDIR/pear/catalog tmp/pear
	cp $SRCDIR/pear/packages/* tmp/pear/packages
	cp $SRCDIR/pear/install-pear.php $SRCDIR/pear/package.dtd tmp/pear
	cp $SRCDIR/pear/template.spec tmp/pear
	cp $SRCDIR/pear/*.xml $SRCDIR/pear/*.xml tmp/pear
	cp -r $SRCDIR/pear/scripts tmp/pear
	cp $SRCDIR/php.ini-recommended tmp/php/php.ini
	cp tmp/pear/scripts/pear.in tmp/scripts
	# We have to copy the additional pear packages
	cp $SRCDIR/../../pearpkgs/*.tgz tmp/pear
}

# First, install the apache 1.X.X version
export SRCDIR=$CURDIR/../../$1/APACHE1
export BLDROOT=$CURDIR/../../bin/$1/APACHE1
mkdir -p $BLDROOT/usr/lib/apache/conf
# We need some kind of httpd.conf file to start with
cp /usr/lib/apache/conf/httpd.conf $BLDROOT/usr/lib/apache/conf
cd $CURDIR/../../$1/APACHE1
make INSTALL_ROOT=$BLDROOT install
fix_bintree $BLDROOT

# Then, install the apache 2.X.X version
export SRCDIR=$CURDIR/../../$1/APACHE2
export BLDROOT=$CURDIR/../../bin/$1/APACHE2
mkdir -p $BLDROOT/opt/apache2/conf
# We need some kind of httpd.conf file to start with
cp /opt/apache2/conf/httpd.conf $BLDROOT/opt/apache2/conf
cd $CURDIR/../../$1/APACHE2
make INSTALL_ROOT=$BLDROOT install
fix_bintree $BLDROOT
# Install the php http config file
mkdir -p $BLDROOT/opt/apache2/conf/conf.d
cp $SRCDIR/../php4.conf $BLDROOT/opt/apache2/conf/conf.d
