#!/usr/bin/ksh

set -x

CURDIR=`pwd`

#
# Build for each version of apache
#
for bdir in APACHE1 APACHE2; do
	if [ $bdir = "APACHE1" ]; then
		PKG="php"
	else
		PKG="php4"
	fi
	# Copy packaging files
	cp pkg/* ../../bin/$1/$bdir

	cd ../../bin/$1/$bdir

	# Get the copyright file from the LICENSE file
	cp ../../../$1/LICENSE copyright

	# Fix the pkginfo file
	perl -pi -e "s%:PKG:%$PKG%g" pkginfo
	if [ "$PKG" = "php" ]; then
		perl -pi -e "s%:PKGNAME:%php - php pkg%g" pkginfo
		perl -pi -e "s%:APACHE_ROOT:%/usr/lib/apache%g" pkginfo
	else
		perl -pi -e "s%:PKGNAME:%PHP: Hypertext Preprocessor%g" pkginfo
		perl -pi -e "s%:APACHE_ROOT:%/opt/apache2%g" pkginfo
	fi

	if [ "$PKG" = "php" ]; then
		BDIR="usr"
		PEARBIN=/usr/bin/pear
		CFILE=/usr/etc/pear.conf
	else
		BDIR="opt"
		PEARBIN=/opt/bin/pear
		CFILE=/opt/etc/pear.conf
		# Fix the depend file for apache2
		perl -pi -e "s%apache%apache2%g" depend
	fi

	# Create the postinstall
	cp postinstall.top postinstall
	# Add the installation of additional pear packages
	echo "\n# Add additional pear packages" >> postinstall
	# Note: order is important here
	for pkg in Net_URL HTTP_Request Mail_Mime Net_DIME
	do
		echo "$PEARBIN install /tmp/pear/${pkg}.tgz" >> postinstall
	done
	echo "\n# Do all the installf's" >> postinstall
	echo "echo \"installf..\\\\c\"" >> postinstall
	cp php.installf php_installf
	if [ "$PKG" = "php" ]; then
		echo "installf $PKG /usr/lib/apache/libexec/libphp4.so f 0755 root sys" >> php_installf
	else
		echo "installf $PKG /opt/apache2/modules/libphp4.so f 0755 root sys" >> php_installf
		echo "installf $PKG /opt/apache2/modules/libphp4.so.0.0.0=./libphp4.so s" >> php_installf
		perl -pi -e '
			s% php % php4 %g;
			s% /usr/lib/php/% /opt/lib/php/%g;
		' php_installf
	fi
	echo "installf $PKG $CFILE f 0644 root sys" >> php_installf

	# Split up all the installf's and add it to postinstall
	let numl=$(cat php_installf|wc -l)/10
	/usr/bin/split -l $numl -a 1 php_installf php_insf.
	cat php_insf.[k-z] >> php_insf.j
	rm -f php_insf.[k-z]
	let pct=0
	for file in php_insf.*; do
		let pct+=10
		cat $file >> postinstall
		rm $file
		echo "echo \" $pct%\\\\c\"" >> postinstall
	done
	echo "echo" >> postinstall
	# Add the removal of /tmp files
	echo "\n# remove files and directories in /tmp" >> postinstall
	find tmp -depth | sed -e "s%^.*%removef $PKG /&%g" >> postinstall
	echo "removef -f $PKG" >> postinstall
	echo "installf -f $PKG" >> postinstall
	echo "rm -rf /tmp/pear /tmp/php /tmp/scripts" >> postinstall
	cat postinstall.bottom >> postinstall

	# Now, do the prototyping
	> prototype
	if [ -f prototype.i ]; then
		cp prototype.i prototype
	fi

	pkgproto -c $PKG tmp >> prototype
	pkgproto -c $PKG $BDIR >> prototype
	perl -pi -e "s%^f $PKG tmp/%v $PKG tmp/%g" prototype

	# Fix the generated prototype
	USR=`id -nu`; GRP=`id -ng`
	perl -pi -e "s%$USR $GRP%root sys%g" prototype
	perl -pi -e '
		s% tmp 0755 root sys% tmp ? ? ?%g;
		s% usr 0755 root sys% usr ? ? ?%g;
		s% usr/bin 0755 root sys% usr/bin ? ? ?%g;
		s% usr/include 0755 root sys% usr/include ? ? ?%g;
		s% usr/lib 0755 root sys% usr/lib ? ? ?%g;
	' prototype

	# The directory for the pear config file
	if [ "$PKG" = "php" ]; then
		perl -pi -e "s% usr/etc 0755 root sys% usr/etc 0755 bin bin%g" prototype
	else
		perl -pi -e "s% opt/etc 0755 root sys% opt/etc 0755 bin bin%g" prototype
	fi

	# Generate a directory structure package
	rm -rf ../../../image/$PKG
	pkgmk -c -o -B 512 -p "$PKG `date '+%m/%d/%y'`" -r `pwd` -d `pwd`/../../../image

	# And generate a data stream for the package
	cd ../../../image
	pkgtrans -o -s $PWD $PWD/$PKG.pkg $PKG

	cd $CURDIR
done
