#!/usr/bin/ksh

set -x

CURDIR=`pwd`
IMGDIR=$CURDIR/../../image
BINDIR=$CURDIR/../../bin/$1

# Put the packaging files into the bin dir
rm -rf $BINDIR
mkdir -p $BINDIR
cp pkg/* $BINDIR

cd $BINDIR

# Figure out the packages we're packaging
PKGS="`grep '^CLASSES' pkginfo | cut -d'=' -f2-`"

# Now, do the prototyping
echo "!PKGS=../../image\n" > prototype
if [ -f prototype.i ]; then
	cat prototype.i >> prototype
fi
# Go through all the packages, and obtain the install files we need
for PKG in $PKGS
do
	if [ -n "`grep ' i copyright ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/copyright=\$PKGS/$PKG/install/copyright" >> prototype
	fi
	if [ -n "`grep ' i depend ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/depend=\$PKGS/$PKG/install/depend" >> prototype
	fi
	if [ -n "`grep ' i pkginfo ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/pkginfo=\$PKGS/$PKG/pkginfo" >> prototype
	fi
	if [ -n "`grep ' i postinstall ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/postinstall=\$PKGS/$PKG/install/postinstall" >> prototype
	fi
	if [ -n "`grep ' i postremove ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/postremove=\$PKGS/$PKG/install/postremove" >> prototype
	fi
	if [ -n "`grep ' i preinstall ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/preinstall=\$PKGS/$PKG/install/preinstall" >> prototype
	fi
	if [ -n "`grep ' i preremove ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/preremove=\$PKGS/$PKG/install/preremove" >> prototype
	fi
	if [ -n "`grep ' i request ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/request=\$PKGS/$PKG/install/request" >> prototype
	fi
	if [ -n "`grep ' i response ' $IMGDIR/$PKG/pkgmap`" ]; then
		echo "i $PKG/response=\$PKGS/$PKG/install/response" >> prototype
	fi
done

# Now, actually make the set
rm -rf ../../image/$1
mkdir ../../image/$1

cd ../../bin/$1

# Generate a directory structure set
pkgmk -c -o -B 512 -p "$1 `date '+%Y-%b-%d %H:%M'`" -r `pwd` -d `pwd`/../../image -l 2876 -aIA32 WORK=`pwd` PKGBINLOC=`pwd`/../../image

# And generate a data stream for the package
cd ../../image
pkgtrans -o -s $PWD $PWD/$1.pkg $1 $PKGS

cd $CURDIR
