#!/usr/bin/ksh

set -x

PKG=soaplite

CURDIR=`pwd`

# Copy packaging files
cp pkg/* ../../bin/$1

cd ../../bin/$1

# Get the Copyright file from within the README
> copyright
for file in ../../$1/*/README; do
	if [ -n "`echo $file | grep XML`" ]; then
		# Cut the part out from XML README
		perl -e '
			foreach (<STDIN>) {
				if (/Perl/) {
					print $_;
					exit 0;
				} else {
					print $_;
				}
			}
		' < $file >> copyright
	else
		# Cut the part out from SOAP::Lite README
		perl -e '
			local ($s) = 0;
			foreach (<STDIN>) {
				if ($s == 2 && /^AUTHOR/) {
					exit 0;
				}
				if ($s == 2) {
					print $_;
				}
				if ($s == 1 && /^COPYRIGHT/) {
					$s = 2;
				}
				if ($s == 0) {
					print $_;
					$s = 1;
				}
				if ($s == 0) {
					print $_;
				}
			}
		' < $file >> copyright
	fi
done

# Now, do the prototyping
> prototype
if [ -f prototype.i ]; then
	cp prototype.i prototype
fi

pkgproto -c soaplite opt >> prototype

# Fix the generated prototype
USR=`id -nu`; GRP=`id -ng`
perl -pi -e "s%$USR $GRP%root sys%g;
		s% opt .*% opt ? ? ?%g;
		s% opt/bin .*% opt/bin ? ? ?%g;
		s% opt/lib .*% opt/lib ? ? ?%g;
		s% opt/lib/perl5 .*% opt/lib/perl5 ? ? ?%g;
		s% opt/lib/perl5/5.8.3 .*% opt/lib/perl5/5.8.3 ? ? ?%g;
		s% opt/lib/perl5/5.8.3/i386-unixware-thread-multi .*% opt/lib/perl5/5.8.3/i386-unixware-thread-multi ? ? ?%g;
		s% opt/lib/perl5/site_perl .*% opt/lib/perl5/site_perl ? ? ?%g;
		s% opt/lib/perl5/site_perl/5.8.3 .*% opt/lib/perl5/site_perl/5.8.3 ? ? ?%g;
		s% opt/lib/perl5/site_perl/5.8.3/i386-unixware-thread-multi .*% opt/lib/perl5/site_perl/5.8.3/i386-unixware-thread-multi ? ? ?%g;
		s% opt/lib/perl5/site_perl/5.8.3/i386-unixware-thread-multi/auto .*% opt/lib/perl5/site_perl/5.8.3/i386-unixware-thread-multi/auto ? ? ?%g;
		s% opt/man .*% opt/man ? ? ?%g;
		s% opt/man/man1 .*% opt/man/man1 ? ? ?%g;
		s% opt/man/man3 .*% opt/man/man3 ? ? ?%g;
		" prototype

# Generate a directory structure package
rm -rf ../../image/$PKG
pkgmk -c -o -B 512 -p "$PKG `date '+%m/%d/%y'`" -r `pwd` -d `pwd`/../../image

# And generate a data stream for the package
cd ../../image
pkgtrans -o -s $PWD $PWD/$PKG.pkg $PKG

cd $CURDIR
